TTab: Truth table

View source: R/TTab.R

TTabR Documentation

Truth table

Description

Internal function to evaluate the importance of predictor combinations within a logic regression tree. This function is called by prime.imp and is not intended to be used independently.

Usage

TTab(data, tree, Xs, mtype)

Arguments

data

A data frame containing input predictors.

tree

An object of class logregtree representing a logic regression tree constructed for a sample.

Xs

A vector of predictor names corresponding to columns in data.

mtype

Model type: 1 = classification, 2 = linear regression, 3 = survival regression, 4 = other.

Details

Generates a matrix of all binary interactions contained in a single sample's logic regression tree. Only predictors included in the logic regression tree are included in the matrix. The resulting matrix can be used to evaluate the importance of specific predictor combinations.

Value

A matrix mat.truth of binary predictor values corresponding to the predictions of the logic tree. Rows correspond to all permutations of predictors included in the tree that yield the "truth" outcome.

Author(s)

Bethany J. Wolf wolfb@musc.edu

References

Wolf BJ, Hill EG, Slate EH. Logic Forest: an ensemble classifier for discovering logical combinations of binary markers. Bioinformatics. 2010;26(17):2183-2189. doi:10.1093/bioinformatics/btq354

See Also

prime.imp


LogicForest documentation built on Feb. 14, 2026, 1:08 a.m.