| find.ctree | R Documentation |
Constructs the complement of a given logic regression tree and computes the complement of its prime interactions (PIs).
find.ctree(tree)
tree |
An object of class |
This is an internal function called by pimp.import and is not intended
for independent use. It generates a new "logregtree" object where the
complements of the original tree's structure and PIs are calculated.
An object of class "logregtree" that is the complement of tree.
Bethany Wolf wolfb@musc.edu
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.