print.LFprediction: Print Method for Logic Forest Predictions

View source: R/print.LFprediction.R

print.LFpredictionR Documentation

Print Method for Logic Forest Predictions

Description

Displays predictions from a logic forest model, including the predicted classes and, for classification models, the proportion of trees predicting a class of one.

Usage

## S3 method for class 'LFprediction'
print(x, ...)

Arguments

x

An object of class "LFprediction".

...

Additional arguments (currently ignored).

Details

For classification models, this method prints the predicted classes for each observation and the proportion of trees in the logic forest that predict class 1. For linear regression models, it prints the predicted values and, if available, the out-of-bag mean squared error.

Value

No return value. This function is called for its side effects (printing).

Author(s)

Bethany Wolf wolfb@musc.edu

See Also

predict.logforest


LogicForest documentation built on Feb. 14, 2026, 1:08 a.m.