print.logforest: Print Method for Logic Forest Models

View source: R/print.logforest.R

print.logforestR Documentation

Print Method for Logic Forest Models

Description

Prints the most important predictors and interactions from a fitted logic forest model, along with their importance scores and frequency of occurrence.

Usage

## S3 method for class 'logforest'
print(x, sortby = "importance", ...)

Arguments

x

An object of class "logforest".

sortby

Character string specifying whether to sort the output by "importance" (default) or "frequency".

...

Additional arguments (currently ignored).

Details

This method displays a matrix of the top predictors and interactions from a logic forest model. If x$norm = TRUE, the variable importance scores are normalized such that the largest score is 1 and all other scores are scaled accordingly.

Value

No return value. This function is called for its side effect of printing.

Author(s)

Bethany Wolf wolfb@musc.edu

See Also

logforest


LogicForest documentation built on Feb. 14, 2026, 1:08 a.m.