| Perms | R Documentation |
Creates a matrix representing all possible combinations of N binary variables. Each row corresponds to a unique combination, and each column represents a variable where 1 indicates inclusion and 0 indicates exclusion.
Perms(n)
n |
Integer. Number of variables to generate permutations for. |
This is an internal function called by TTab and is not intended for independent use.
A matrix with 2^n rows and n columns, where each row is a unique permutation of 0s and 1s.
Bethany Wolf wolfb@musc.edu
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.