| TTab | R Documentation |
Internal function to evaluate the importance of predictor combinations within a logic regression tree.
This function is called by prime.imp and is not intended to be used independently.
TTab(data, tree, Xs, mtype)
data |
A data frame containing input predictors. |
tree |
An object of class |
Xs |
A vector of predictor names corresponding to columns in |
mtype |
Model type: 1 = classification, 2 = linear regression, 3 = survival regression, 4 = other. |
Generates a matrix of all binary interactions contained in a single sample's logic regression tree. Only predictors included in the logic regression tree are included in the matrix. The resulting matrix can be used to evaluate the importance of specific predictor combinations.
A matrix mat.truth of binary predictor values corresponding to the predictions of the logic tree.
Rows correspond to all permutations of predictors included in the tree that yield the "truth" outcome.
Bethany J. Wolf wolfb@musc.edu
Wolf BJ, Hill EG, Slate EH. Logic Forest: an ensemble classifier for discovering logical combinations of binary markers. Bioinformatics. 2010;26(17):2183-2189. doi:10.1093/bioinformatics/btq354
prime.imp
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.