| pimp.import | R Documentation |
Calculates permutation-based importance measures for individual predictors and interactions within a logic regression tree in a logic forest.
pimp.import(fit, data, testdata, BSpred, pred, Xs, mtype)
fit |
Fitted logic regression tree object containing outcome, model type, and logic tree information. |
data |
In-bag sample (training data). |
testdata |
Out-of-bag sample (test data). |
BSpred |
Number of predictors included in the interactions (includes NOT-ed variables). |
pred |
Number of predictors in the model (used for constructing permuted matrices). |
Xs |
Matrix or data frame of 0/1 values representing all predictor variables. |
mtype |
Model type: |
This function calculates importance measures for each bootstrapped sample by comparing model fit between the original out-of-bag sample and a permuted out-of-bag sample. Model fit is evaluated using:
Misclassification rate for classification models,
Log2 mean squared error for linear regression,
Harrell's C-index for survival regression (Cox-PH or exponential time-to-event models).
A list with the following components:
Vector of importance estimates for individual predictors.
Vector of importance estimates for interactions (pimps).
Matrix indicating which predictors (and NOT-ed predictors) are used in each interaction.
Vector of predictor IDs used in the tree.
Vector of predictor column indices corresponding to vec.Xvars.
Bethany J. Wolf wolfb@musc.edu
J. Madison Hyer madison.hyer@osumc.edu
Wolf BJ, Hill EG, Slate EH. Logic Forest: an ensemble classifier for discovering logical combinations of binary markers. Bioinformatics. 2010;26(17):2183–2189. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/bioinformatics/btq354")}
logforest
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.