| prime.imp | R Documentation |
Internal function called by pimp.import.
It is not intended to be used independently.
Generates a list of all variables and variable interactions identified by a specific
logic regression tree within a logic forest or LBoost model.
prime.imp(tree, data, Xs, mtype)
tree |
An object of class |
data |
Data frame used to fit the logic forest. |
Xs |
A vector of predictor names corresponding to columns in |
mtype |
Model type (e.g., classification, linear regression, survival regression). |
This function constructs all possible interactions of the predictors contained in the tree, identifies those that contribute to a positive outcome ("prime interactions"), and returns information about which variables and interactions are included in each.
An object of class "primeImp" with the following elements:
vec.primes |
Character vector of variable interactions in logical format. |
tmp.mat |
Matrix of all binary interactions contained in the tree. |
vec.pimpvars |
Sorted vector of column indices in |
list.pimps |
List of vectors, each containing indices of predictors involved in each interaction. |
Bethany Wolf wolfb@musc.edu
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.