Internal function called by pimp.import.
It is not intended to be used independently.
Generates a list of all variables and variable interactions identified by a specific
logic regression tree within a logic forest or LBoost model.
prime.imp(tree, data, Xs, mtype)An object of class "primeImp" with the following elements:
Character vector of variable interactions in logical format (negated predictors prefixed with !).
Matrix of all binary interactions considered for the tree.
Sorted vector of unique predictor indices involved in any prime interaction.
List of vectors, each containing indices of predictors involved in each interaction.
An object of class "logregtree" representing a fitted logic regression tree.
A data frame containing predictor variables used to fit the logic forest. Columns
should correspond exactly to the variables specified in Xs.
A character vector of predictor names corresponding to columns in data.
Model type (e.g., classification, linear regression, survival regression).
Bethany Wolf wolfb@musc.edu
This function constructs all possible interactions of the predictors contained in
the tree, identifies those that contribute to a positive outcome ("prime interactions"),
and returns information about which variables and interactions are included in each.
Negated predictors are indicated with a ! prefix in the vec.primes output.
pimp.import