View source: R/print.logforest.R
| print.logforest | R Documentation |
Prints the most important predictors and interactions from a fitted logic forest model, along with their importance scores and frequency of occurrence.
## S3 method for class 'logforest'
print(x, sortby = "importance", ...)
x |
An object of class |
sortby |
Character string specifying whether to sort the output by |
... |
Additional arguments (currently ignored). |
This method displays a matrix of the top predictors and interactions from a logic forest model.
If x$norm = TRUE, the variable importance scores are normalized such that the largest
score is 1 and all other scores are scaled accordingly.
No return value. This function is called for its side effect of printing.
Bethany Wolf wolfb@musc.edu
logforest
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.